@@ -278,7 +278,7 @@ forecast.gts <- function(
   pfcasts <- sapply(loopout, function(x) x$pfcasts)
   
   if (any(pfcasts < 0) && nonnegative) {
-    fcasts[pfcasts < 0] <- 0
+    pfcasts[pfcasts < 0] <- 0
     warning("Negative base forecasts are truncated to zero.")
   }
   
